(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{63:function(e,t,a){e.exports=a(79)},79:function(e,t,a){"use strict";a.r(t);var r=a(5),n=a.n(r),l=a(52),c=a.n(l),o=a(0),i=a(1),s=a(2),p=a(3),u=a(49),m=a(101),b=a(105),d=a(104),E=a(103),g=a(106),h=a(100),v=a(58),f=a.n(v),y=(a(71),a(72),a(73),a(74),function(e){Object(s.a)(a,e);var t=Object(p.a)(a);function a(){var e;Object(i.a)(this,a);for(var r=arguments.length,l=new Array(r),c=0;c<r;c++)l[c]=arguments[c];return(e=t.call.apply(t,[this].concat(l))).render=function(){var t=e.props.args.title,a=e.props.args.subtitle,r=e.props.args.body,l=e.props.args.link;return n.a.createElement("div",{style:{padding:"0.5rem"}},n.a.createElement(m.a,{variant:"outlined"},n.a.createElement(g.a,{title:t,subheader:a}),n.a.createElement(d.a,null,n.a.createElement(E.a,{variant:"body2"},r)),n.a.createElement(b.a,null,n.a.createElement(h.a,{"aria-label":"open url",href:l,target:"_PARENT"},n.a.createElement(f.a,null)))))},e}return Object(o.a)(a)}(u.a)),j=Object(u.b)(y);c.a.render(n.a.createElement(n.a.StrictMode,null,n.a.createElement(j,null)),document.getElementById("root"))}},[[63,1,2]]]);
//# sourceMappingURL=main.2e6a0890.chunk.js.map